@@ -33,8 +33,10 @@
 
 (** Operations on audio data. *)
 
+(** At given sample rate, number of samples in given amount of time. *)
 val samples_of_seconds : int -> float -> int
 
+(** At given sample rate, duration of given number of samples. *)
 val seconds_of_samples : int -> int -> float
 
 (** Convert decibels to linear coefficient. *)
@@ -96,6 +98,8 @@ module Mono : sig
   (** Clear a portion of a buffer (fill it with zeroes). *)
   val clear : buffer -> int -> int -> unit
 
+  val amplify : float -> buffer -> int -> int -> unit
+
   val resample : ?mode:[`Nearest | `Linear] -> float -> buffer -> int -> int -> buffer
 
   val clip : buffer -> int -> int -> unit
@@ -317,6 +321,30 @@ module S16LE : sig
   val to_audio : string -> int -> buffer -> int -> int -> unit
 end
 
+module S16BE : sig
+  val length : int -> int -> int
+
+  val duration : int -> int -> int
+
+  val of_audio : buffer -> int -> string -> int -> int -> unit
+
+  val make : buffer -> int -> int -> string
+
+  val to_audio : string -> int -> buffer -> int -> int -> unit
+end
+
+module S24LE : sig
+  val of_audio : buffer -> int -> string -> int -> int -> unit
+
+  val to_audio : string -> int -> buffer -> int -> int -> unit
+end
+
+module S32LE : sig
+  val of_audio : buffer -> int -> string -> int -> int -> unit
+
+  val to_audio : string -> int -> buffer -> int -> int -> unit
+end
+
 val resample : ?mode:[`Nearest | `Linear] -> float -> buffer -> int -> int -> buffer
 
 (** Same as [Array.blit] for audio data. *)
